@@ -1,7 +1,7 @@
 #!/usr/bin/python
-from __future__ import unicode_literals, division, absolute_import
+from __future__ import unicode_literals, division, absolute_import, print_function
 
-__version__ = '1.2.196'
+__version__ = '1.2.197'
 
 import logging
 import os
@@ -26,7 +26,7 @@ def main(args=None):
     try:
         manager = Manager(options)
     except (IOError, ValueError) as e:
-        log.critical('Could not initialize manager: %s' % e)
+        print('Could not initialize manager: %s' % e, file=sys.stderr)
         sys.exit(1)
 
     if options.profile:
